@@ -19,11 +19,12 @@ use stm32_hal::{
     pac::{self, ADC1, EXTI},
     prelude::*,
     rtc::{Rtc, RtcClockSource, RtcConfig},
-    timer::{Event::TimeOut, Timer},
+    timer::{Timer, TimerInterrupt},
 };
 
 // Copy type variables can go in `Cell`s, which are easier to access.
 static SENSOR_READING: Mutex<Cell<f32>> = Mutex::new(Cell::new(335.));
+static BOUNCING: Mutex<Cell<bool>> = Mutex::new(Cell::new(false));
 
 // More complex values go in `RefCell`s. Use an option, since we need to set this up
 // before we initialize the peripheral it stores.
@@ -50,19 +51,22 @@ fn main() -> ! {
     button.enable_interrupt(Edge::Falling, &mut dp.EXTI, &mut dp.SYSCFG);
 
     // Set up and start a timer; set it to fire interrupts every 5 seconds.
-    let mut timer_1 = Timer::new_tim3(dp.TIM3, 0.2, &clock_cfg, &mut dp.RCC);
-    timer.listen(TimeOut); // Enable update event interrupts.
-    timer_1.enable();
+    let mut timer = Timer::new_tim3(dp.TIM3, 0.2, &clock_cfg, &mut dp.RCC);
+    timer.enable_interrupt(TimerInterrupt::Update); // Enable update event interrupts.
+    timer.enable();
 
     let mut debounce_timer = Timer::new_tim15(dp.TIM15, 5., &clock_cfg, &mut dp.RCC);
-    debounce_timer.listen(TimeOut); // Enable update event interrupts.
+    debounce_timer.enable_interrupt(TimerInterrupt::Update); // Enable update event interrupts.
 
     // Set up the realtime clock.
     let mut rtc = Rtc::new(
         dp.RTC,
         &mut dp.RCC,
         &mut dp.PWR,
-        RtcConfig::default().clock_source(RtcClockSource::Lse), // .bypass_lse_output(true)
+        RtcConfig {
+            clock_source: RtcClockSource::Lse,
+            ..Default::default()
+        },
     );
 
     // Set the RTC to trigger an interrupt every 30 seconds.
@@ -85,9 +89,10 @@ fn main() -> ! {
     unsafe {
         NVIC::unmask(pac::Interrupt::EXTI0); // GPIO
         NVIC::unmask(pac::Interrupt::TIM3); // Timer
+        NVIC::unmask(pac::Interrupt::TIM15); // Timer
         NVIC::unmask(pac::Interrupt::RTC_WKUP); // RTC
 
-        // I'm leaving this priority-setting code in for future reference.
+        // Set interrupt priority. See the reference manual's NVIC section for details.
         cp.NVIC.set_priority(pac::Interrupt::EXTI0, 0);
         cp.NVIC.set_priority(pac::Interrupt::TIM3, 1);
     }
@@ -103,6 +108,9 @@ fn main() -> ! {
             &clock_cfg,
             &mut dp.RCC,
         );
+
+        // Turn back on the PLL.
+        clocks.reselect_input();
     }
 }
 
@@ -115,6 +123,13 @@ fn EXTI0() {
             (*pac::EXTI::ptr()).pr1.modify(|_, w| w.pr0().set_bit());
         }
 
+        let bouncing = BOUNCING.borrow(cs);
+        if bouncing.get() {
+            return;
+        }
+        unsafe { (*pac::TIM15::ptr()).cr1.modify(|_, w| w.cen().set_bit()) }
+        bouncing.set(true);
+
         // Update our global sensor reading. This section dmeonstrates boilerplate
         // for Mutexes etc.
         // Alternative syntax using a convenience macro:
@@ -177,10 +192,9 @@ fn TIM15() {
     free(|cs| {
         unsafe { (*pac::TIM15::ptr()).sr.modify(|_, w| w.uif().set_bit()) }
 
-        // BOUNCING.borrow(cs).set(false);
+        BOUNCING.borrow(cs).set(false);
 
-        defmt::info!("DEBOUNCE FIRED");
         // Disable the timer until next time you press a button.
-        debounce_timer.disable();
+        unsafe { (*pac::TIM15::ptr()).cr1.modify(|_, w| w.cen().clear_bit()) }
     });
 }
