@@ -78,7 +78,7 @@ pub enum AdcInterrupt {
     InjectedOverflow,
 }
 
-/// Analog to Digital converter peripheral
+/// Represents an Analog to Digital Converter (ADC) peripheral.
 pub struct Adc<ADC> {
     /// ADC Register
     regs: ADC,
@@ -335,13 +335,9 @@ macro_rules! hal {
                     panic!("ADC sequence length must be in 1..=16")
                 }
 
-                // todo: Swap these once the next version of the PACs are out.
                 // self.regs.sqr1.modify(|_, w| unsafe { w.l().bits(len - 1) });
                 cfg_if! {
-                    // todo: We've put l4x2 on the newer one, since we're using the workaround local
-                    // todo PAC, which has the newer approach.
-                    // if #[cfg(any(feature = "l4x1", feature = "l4x2", feature = "l4x3", feature = "l4x5"))] {
-                    if #[cfg(any(feature = "l4x1", feature = "l4x3", feature = "l4x5"))] {
+                    if #[cfg(any(feature = "l4x1", feature = "l4x2", feature = "l4x3", feature = "l4x5"))] {
                         self.regs.sqr1.modify(|_, w| unsafe { w.l3().bits(len - 1) });
                     } else {
                         self.regs.sqr1.modify(|_, w| unsafe { w.l().bits(len - 1) });
