@@ -56,6 +56,8 @@ pub enum InputSrc {
     Hsi,
     Hse(u32), // freq in Mhz
     Pll(PllSrc),
+    // #[cfg(feature = "f4")]
+    // Pllr(PllSrc), // Not available on all variants.
 }
 
 impl InputSrc {
@@ -66,6 +68,8 @@ impl InputSrc {
             Self::Hsi => 0b00,
             Self::Hse(_) => 0b01,
             Self::Pll(_) => 0b10,
+            // #[cfg(feature = "f4")]
+            // Self::Pllr(_) => 0b11,
         }
     }
 }
@@ -171,6 +175,18 @@ pub enum Pllp {
     Div8 = 0b11,
 }
 
+#[cfg(feature = "f4")]
+impl Pllp {
+    pub fn value(&self) -> u8 {
+        match self {
+            Self::Div2 => 2,
+            Self::Div4 => 4,
+            Self::Div6 => 6,
+            Self::Div8 => 8,
+        }
+    }
+}
+
 #[derive(Clone, Copy)]
 #[repr(u8)]
 /// Division factor for the AHB clock. Also known as AHB Prescaler.
@@ -360,10 +376,7 @@ impl Clocks {
 
         // Adjust flash wait states according to the HCLK frequency.
         // We need to do this before enabling PLL, or it won't enable.
-        #[cfg(feature = "f3")]
-        let sysclk = calc_sysclock(self.input_src, self.prediv, self.pll_mul);
-        #[cfg(feature = "f4")]
-        let sysclk = calc_sysclock(self.input_src, self.pllm, self.plln, self.pllp);
+        let sysclk = self.calc_sysclock();
 
         // todo: We don't yet take into account other voltage settings for f4 wait states.
         let hclk = sysclk / self.hclk_prescaler.value() as u32;
@@ -519,7 +532,7 @@ impl Clocks {
 
     /// Re-select innput source; used on Stop and Standby modes, where the system reverts
     /// to HSI after wake.
-    pub(crate) fn re_select_input(&self, rcc: &mut RCC) {
+    pub fn reselect_input(&self, rcc: &mut RCC) {
         // Re-select the input source; it will revert to HSI during `Stop` or `Standby` mode.
 
         // Note: It would save code repetition to pass the `Clocks` struct in and re-run setup
@@ -549,14 +562,62 @@ impl Clocks {
             InputSrc::Hsi => (), // Already reset to this.
         }
     }
+
+    #[cfg(feature = "f3")]
+    /// Calculate the systick, and input frequency, in  Hz.
+    fn calc_sysclock(&self) -> u32 {
+        match self.input_src {
+            InputSrc::Pll(pll_src) => match pll_src {
+                PllSrc::HsiDiv2 => 4_000_000 * self.pll_mul.value() as u32,
+                PllSrc::Hse(freq) => {
+                    freq / self.prediv.value() as u32 * self.pll_mul.value() as u32
+                }
+            },
+            InputSrc::Hsi => 8_000_000,
+            InputSrc::Hse(freq) => freq,
+        }
+    }
+
+    #[cfg(feature = "f4")]
+    /// Calculate the systick, and input frequency.
+    fn calc_sysclock(&self) -> u32 {
+        let sysclk = match self.input_src {
+            InputSrc::Hsi => 16_000_000,
+            InputSrc::Hse(freq) => freq,
+            InputSrc::Pll(pll_src) => {
+                let input_freq = match pll_src {
+                    PllSrc::Hsi => 16_000_000,
+                    PllSrc::Hse(freq) => freq,
+                };
+                input_freq / self.pllm as u32 * self.plln as u32 / self.pllp.value() as u32
+            } // InputSrc::Pllr(pll_src) => {
+              //     let input_freq = match pll_src {
+              //         PllSrc::Hsi => 16_000_000,
+              //         PllSrc::Hse(freq) => freq,
+              //     };
+              //     input_freq / self.pllm as u32 * self.plln as u32 / self.pllr.value() as u32
+              // }
+        };
+
+        sysclk
+    }
+
+    /// Check if the PLL is enabled. This is useful if checking wheather to re-enable the PLL
+    /// after exiting Stop or Standby modes, eg so you don't re-enable if it was already re-enabled
+    /// in a different context. eg:
+    /// ```
+    /// if !clock_cfg.pll_is_enabled() {
+    ///     clock_cfg.reselect_input(&mut dp.RCC);
+    ///}
+    ///```
+    pub fn pll_is_enabled(&self, rcc: &mut RCC) -> bool {
+        rcc.cr.read().pllon().bit_is_set()
+    }
 }
 
 impl ClockCfg for Clocks {
     fn sysclk(&self) -> u32 {
-        #[cfg(feature = "f3")]
-        return calc_sysclock(self.input_src, self.prediv, self.pll_mul);
-        #[cfg(feature = "f4")]
-        return calc_sysclock(self.input_src, self.pllm, self.plln, self.pllp);
+        return self.calc_sysclock();
     }
 
     fn hclk(&self) -> u32 {
@@ -669,34 +730,3 @@ impl Default for Clocks {
         }
     }
 }
-
-#[cfg(feature = "f3")]
-/// Calculate the systick, and input frequency, in  Hz.
-fn calc_sysclock(input_src: InputSrc, prediv: Prediv, pll_mul: PllMul) -> u32 {
-    match input_src {
-        InputSrc::Pll(pll_src) => match pll_src {
-            PllSrc::HsiDiv2 => 4_000_000 * pll_mul.value() as u32,
-            PllSrc::Hse(freq) => freq / prediv.value() as u32 * pll_mul.value() as u32,
-        },
-        InputSrc::Hsi => 8_000_000,
-        InputSrc::Hse(freq) => freq,
-    }
-}
-
-#[cfg(feature = "f4")]
-/// Calculate the systick, and input frequency.
-fn calc_sysclock(input_src: InputSrc, pllm: u8, plln: u16, pllp: Pllp) -> u32 {
-    let sysclk = match input_src {
-        InputSrc::Pll(pll_src) => {
-            let input_freq = match pll_src {
-                PllSrc::Hsi => 16_000_000,
-                PllSrc::Hse(freq) => freq,
-            };
-            input_freq / pllm as u32 * plln as u32 / pllp as u8 as u32
-        }
-        InputSrc::Hsi => 16_000_000,
-        InputSrc::Hse(freq) => freq,
-    };
-
-    sysclk
-}
