@@ -11,9 +11,9 @@ cfg_if::cfg_if! {
     if #[cfg(any(feature = "f3", feature = "f4"))] {
         mod f;
         pub use f::*;
-    } else if #[cfg(any(feature = "l4", feature = "l5", feature = "g0", feature = "g4"))] {
-        mod l_g;
-        pub use l_g::*;
+    } else if #[cfg(any(feature = "l4", feature = "l5", feature = "g0", feature = "g4", feature = "wb"))] {
+        mod baseline;
+        pub use baseline::*;
     } else if #[cfg(feature = "u5")] {
         // todo once SVD is out
     } else if #[cfg(feature = "h7")] {
