@@ -1,7 +1,10 @@
 //! Direct Memory Access (DMA). This module handles initialization, and transfer
 //! configuration for DMA. The `Dma::cfg_channel` method is called by modules that use DMA.
 
-use core::{ops::Deref, sync::atomic};
+use core::{
+    ops::Deref,
+    sync::atomic::{self, Ordering},
+};
 
 use crate::{
     pac::{self, RCC},
@@ -13,6 +16,11 @@ use crate::pac::dma;
 #[cfg(not(feature = "g0"))]
 use crate::pac::dma1 as dma;
 
+#[cfg(any(feature = "l5", feature = "g0", feature = "g4"))]
+use pac::DMAMUX;
+#[cfg(feature = "wb")]
+use pac::DMAMUX1 as DMAMUX;
+
 // use embedded_dma::{ReadBuffer, WriteBuffer};
 
 use cfg_if::cfg_if;
@@ -317,6 +325,7 @@ impl Default for ChannelCfg {
     }
 }
 
+/// Represents a Direct Memory Access (DMA) peripheral.
 pub struct Dma<D> {
     regs: D,
 }
@@ -639,7 +648,7 @@ where
         // for info on why we use `compiler_fence` here:
         // "We use Ordering::Release to prevent all preceding memory operations from being moved
         // after [starting DMA], which performs a volatile write."
-        atomic::compiler_fence(atomic::Ordering::Release);
+        atomic::compiler_fence(Ordering::Release);
 
         match channel {
             DmaChannel::C1 => {
@@ -894,13 +903,14 @@ where
         // todo?
 
         // The software waits for the transfer complete or transfer error interrupt.
-        // (Handed by calling code))
+        // (Handed by calling code)
 
         // (todo: set ifcr.cficx bit to clear all interrupts?)
 
         // When a channel transfer error occurs, the EN bit of the DMA_CCRx register is cleared by
         // hardware. This EN bit can not be set again by software to re-activate the channel x, until the
         // TEIFx bit of the DMA_ISR register is set
+        atomic::compiler_fence(Ordering::SeqCst);
     }
 
     pub fn transfer_is_complete(&mut self, channel: DmaChannel) -> bool {
@@ -1227,9 +1237,9 @@ where
 //     }
 // }
 
-#[cfg(any(feature = "l5", feature = "g0", feature = "g4"))]
+#[cfg(any(feature = "l5", feature = "g0", feature = "g4", feature = "wb"))]
 /// Configure a specific DMA channel to work with a specific peripheral.
-pub fn mux(channel: DmaChannel, input: DmaInput, mux: &pac::DMAMUX) {
+pub fn mux(channel: DmaChannel, input: DmaInput, mux: &DMAMUX) {
     // Note: This is similar in API and purpose to `channel_select` above,
     // for different families. We're keeping it as a separate function instead
     // of feature-gating within the same function so the name can be recognizable
