@@ -86,22 +86,22 @@ pub enum CfgLock {
 #[repr(u8)]
 /// Values for `GPIOx_AFRL` and `GPIOx_AFRH`.
 pub enum AltFn {
-    Af0 = 0b0000,
-    Af1 = 0b0001,
-    Af2 = 0b0010,
-    Af3 = 0b0011,
-    Af4 = 0b0100,
-    Af5 = 0b0101,
-    Af6 = 0b0110,
-    Af7 = 0b0111,
-    Af8 = 0b1000,
-    Af9 = 0b1001,
-    Af10 = 0b1010,
-    Af11 = 0b1011,
-    Af12 = 0b1100,
-    Af13 = 0b1101,
-    Af14 = 0b1110,
-    Af15 = 0b1111,
+    Af0 = 0,
+    Af1 = 1,
+    Af2 = 2,
+    Af3 = 3,
+    Af4 = 4,
+    Af5 = 5,
+    Af6 = 6,
+    Af7 = 7,
+    Af8 = 8,
+    Af9 = 9,
+    Af10 = 10,
+    Af11 = 11,
+    Af12 = 12,
+    Af13 = 13,
+    Af14 = 14,
+    Af15 = 15,
 }
 
 #[derive(Copy, Clone)]
@@ -263,13 +263,18 @@ macro_rules! set_exti {
                     PinNum::[<P $num>] => {
                         cfg_if! {
                             if #[cfg(all(feature = "h7", not(any(feature = "h747cm4", feature = "h747cm7"))))] {
-                                $exti.cpuimr1.modify(|_, w| w.[<mr $num>]().unmasked());
+                                $exti.cpuimr1.modify(|_, w| w.[<mr $num>]().set_bit());
                             } else if #[cfg(any(feature = "h747cm4", feature = "h747cm7"))] {
-                                $exti.c1imr1.modify(|_, w| w.[<mr $num>]().unmasked());
-                            }else if #[cfg(feature = "g4")] {
-                                $exti.imr1.modify(|_, w| w.[<im $num>]().unmasked());
+                                $exti.c1imr1.modify(|_, w| w.[<mr $num>]().set_bit());
+                            }else if #[cfg(any(feature = "g4"))] {
+                                $exti.imr1.modify(|_, w| w.[<im $num>]().set_bit());
+                            } else if #[cfg(feature = "wb")] {
+                                // todo: Missing 0-4 in PAC, so we read+write. https://github.com/stm32-rs/stm32-rs/issues/570
+                                let val =  $exti.c1imr1.read().bits();
+                                $exti.c1imr1.write(|w| unsafe { w.bits(val | (1 << $num)) });
+                                // todo: Core 2 interrupts.
                             } else {
-                                $exti.imr1.modify(|_, w| w.[<mr $num>]().unmasked());
+                                $exti.imr1.modify(|_, w| w.[<mr $num>]().set_bit());
                             }
                         }
 
@@ -277,6 +282,13 @@ macro_rules! set_exti {
                             if #[cfg(feature = "g4")] {
                                 $exti.rtsr1.modify(|_, w| w.[<rt $num>]().bit($trigger));
                                 $exti.ftsr1.modify(|_, w| w.[<ft $num>]().bit(!$trigger));
+                            } else if #[cfg(feature = "wb")] {
+                                // todo: Missing in PAC, so we read+write. https://github.com/stm32-rs/stm32-rs/issues/570
+                                let val_r =  $exti.rtsr1.read().bits();
+                                $exti.rtsr1.write(|w| unsafe { w.bits(val_r | (1 << $num)) });
+                                let val_f =  $exti.ftsr1.read().bits();
+                                $exti.ftsr1.write(|w| unsafe { w.bits(val_f | (1 << $num)) });
+                                // todo: Core 2 interrupts.
                             } else {
                                 $exti.rtsr1.modify(|_, w| w.[<tr $num>]().bit($trigger));
                                 $exti.ftsr1.modify(|_, w| w.[<tr $num>]().bit(!$trigger));
@@ -365,9 +377,9 @@ macro_rules! set_alt {
                     $(
                         PinNum::[<P $num>] => {
                             $regs.moder.modify(|_, w| w.[<moder $num>]().bits(PinMode::Alt(AltFn::Af0).val()));
-                            #[cfg(any(feature = "l5", feature = "g0", feature = "h7"))]
+                            #[cfg(any(feature = "l5", feature = "g0", feature = "h7", feature = "wb"))]
                             $regs.[<afr $lh>].modify(|_, w| w.[<$field_af $num>]().bits($val as u8));
-                            #[cfg(not(any(feature = "l5", feature = "g0", feature = "h7")))]
+                            #[cfg(not(any(feature = "l5", feature = "g0", feature = "h7", feature = "wb")))]
                             $regs.[<afr $lh>].modify(|_, w| w.[<$field_af $lh $num>]().bits($val as u8));
                         }
                     )+
@@ -488,7 +500,7 @@ macro_rules! make_pin {
             /// Set up a pin's alternate function. We set this up initially using `mode()`.
             fn alt_fn(&mut self, value: AltFn, regs: &mut pac::[<GPIO $Port>]) {
                 cfg_if! {
-                    if #[cfg(any(feature = "l5", feature = "g0"))] {
+                    if #[cfg(any(feature = "l5", feature = "g0", feature = "wb"))] {
                         set_alt!(self.pin, regs, afsel, value, [(0, l), (1, l), (2, l),
                             (3, l), (4, l), (5, l), (6, l), (7, l), (8, h), (9, h), (10, h), (11, h), (12, h),
                             (13, h), (14, h), (15, h)])
@@ -741,14 +753,25 @@ cfg_if! {
 }
 
 cfg_if! {
-    if #[cfg(not(any(feature = "f301", feature = "f3x4", feature = "f410", feature = "g0")))] {
+    // note: WB has port E, but is missing some field values etc. Not sure if in PAC or actual.
+    if #[cfg(not(any(feature = "f301", feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))] {
         make_port!(E, e);
         make_pin!(E);
     }
 }
 
+// todo: 412 workaround
 cfg_if! {
-    if #[cfg(not(any(feature = "f401", feature = "f410", feature = "f411", feature = "l4x1", feature = "l4x2", feature = "l4x3")))] {
+    if #[cfg(not(any(
+    feature = "f401",
+    feature = "f410",
+    feature = "f411",
+    feature = "l4x1",
+    feature = "l4x2",
+    feature = "l412",
+    feature = "l4x3",
+    feature = "wb"
+    )))] {
         make_port!(F, f);
         make_pin!(F);
     }
@@ -762,7 +785,8 @@ cfg_if! {
         feature = "f410",
         feature = "l4",
         feature = "g0",
-        feature = "g4"
+        feature = "g4",
+        feature = "wb",
     )))] {
         make_port!(H, h);
         make_pin!(H);
