@@ -13,7 +13,7 @@ use crate::{
 
 #[cfg(feature = "g0")]
 use crate::pac::dma as dma_p;
-#[cfg(any(feature = "f3", feature = "l4", feature = "g4"))]
+#[cfg(any(feature = "f3", feature = "l4", feature = "g4", feature = "wb"))]
 use crate::pac::dma1 as dma_p;
 
 #[cfg(not(any(feature = "h7", feature = "f4", feature = "l5")))]
@@ -46,14 +46,15 @@ pub enum Error {
 #[derive(Clone, Copy)]
 pub enum I2cDevice {
     One,
+    #[cfg(not(feature = "wb"))]
     Two,
-    #[cfg(feature = "h7")]
+    #[cfg(any(feature = "h7", feature = "wb"))]
     Three,
 }
 
-/// I2C peripheral operating in master mode
-pub struct I2c<I2C> {
-    regs: I2C,
+/// Represents an Inter-Integrated Circuit (I2C) peripheral.
+pub struct I2c<I> {
+    regs: I,
     device: I2cDevice,
     // mode: I2cMode,
     /// SMBUS features like PEC enabled.
@@ -76,10 +77,11 @@ where
             I2cDevice::One => {
                 rcc_en_reset!(apb1, i2c1, rcc);
             }
+            #[cfg(not(feature = "wb"))]
             I2cDevice::Two => {
                 rcc_en_reset!(apb1, i2c2, rcc);
             }
-            #[cfg(feature = "h7")]
+            #[cfg(any(feature = "h7", feature = "wb"))]
             I2cDevice::Three => {
                 rcc_en_reset!(apb1, i2c3, rcc);
             }
@@ -159,7 +161,7 @@ where
         // Enable the peripheral
         regs.cr1.write(|w| w.pe().set_bit());
 
-        I2c {
+        Self {
             regs,
             device,
             smbus: false,
@@ -277,8 +279,9 @@ where
         #[cfg(any(feature = "f3", feature = "l4"))]
         let channel = match self.device {
             I2cDevice::One => DmaInput::I2c1Tx.dma1_channel(),
+            #[cfg(not(feature = "wb"))]
             I2cDevice::Two => DmaInput::I2c2Tx.dma1_channel(),
-            #[cfg(feature = "h7")]
+            #[cfg(any(feature = "h7", feature = "wb"))]
             I2cDevice::Three => DmaInput::I2c3Tx.dma1_channel(),
         };
 
@@ -286,8 +289,6 @@ where
         match self.device {
             I2cDevice::One => dma.channel_select(DmaInput::I2c1Tx),
             I2cDevice::Two => dma.channel_select(DmaInput::I2c2Tx),
-            #[cfg(feature = "h7")]
-            I2cDevice::Three => dma.channel_select(DmaInput::I2c3Tx),
         }
 
         // DMA (Direct Memory Access) can be enabled for transmission by setting the TXDMAEN bit
@@ -358,8 +359,9 @@ where
         #[cfg(any(feature = "f3", feature = "l4"))]
         let channel = match self.device {
             I2cDevice::One => DmaInput::I2c1Rx.dma1_channel(),
+            #[cfg(not(feature = "wb"))]
             I2cDevice::Two => DmaInput::I2c2Rx.dma1_channel(),
-            #[cfg(feature = "h7")]
+            #[cfg(any(feature = "h7", feature = "wb"))]
             I2cDevice::Three => DmaInput::I231Rx.dma1_channel(),
         };
 
@@ -367,8 +369,6 @@ where
         match self.device {
             I2cDevice::One => dma.channel_select(DmaInput::I2c1Rx),
             I2cDevice::Two => dma.channel_select(DmaInput::I2c2Rx),
-            #[cfg(feature = "h7")]
-            I2cDevice::Three => dma.channel_select(DmaInput::I2c3Rx),
         }
 
         // DMA (Direct Memory Access) can be enabled for reception by setting the RXDMAEN bit in
@@ -447,9 +447,6 @@ where
     type Error = Error;
 
     fn write(&mut self, addr: u8, bytes: &[u8]) -> Result<(), Error> {
-        // TODO support transfers of more than 255 bytes
-        assert!(bytes.len() < 256 && bytes.len() > 0);
-
         // Wait for any previous address sequence to end
         // automatically. This could be up to 50% of a bus
         // cycle (ie. up to 0.5/freq)
@@ -478,9 +475,6 @@ where
     type Error = Error;
 
     fn read(&mut self, addr: u8, bytes: &mut [u8]) -> Result<(), Error> {
-        // TODO support transfers of more than 255 bytes
-        assert!(bytes.len() < 256 && bytes.len() > 0);
-
         // Wait for any previous address sequence to end
         // automatically. This could be up to 50% of a bus
         // cycle (ie. up to 0.5/freq)
@@ -509,10 +503,6 @@ where
     type Error = Error;
 
     fn write_read(&mut self, addr: u8, bytes: &[u8], buffer: &mut [u8]) -> Result<(), Error> {
-        // TODO support transfers of more than 255 bytes
-        assert!(bytes.len() < 256 && bytes.len() > 0);
-        assert!(buffer.len() < 256 && buffer.len() > 0);
-
         // Wait for any previous address sequence to end
         // automatically. This could be up to 50% of a bus
         // cycle (ie. up to 0.5/freq)
