@@ -1,6 +1,10 @@
 //! Serial Peripheral Interface (SPI) bus. Implements traits from `embedded-hal`.
 
-use core::{ops::Deref, ptr};
+use core::{
+    ops::Deref,
+    ptr,
+    sync::atomic::{self, Ordering},
+};
 
 use embedded_hal::spi::{FullDuplex, Mode, Phase, Polarity};
 
@@ -12,7 +16,7 @@ use crate::{
 
 #[cfg(feature = "g0")]
 use crate::pac::dma as dma_p;
-#[cfg(any(feature = "f3", feature = "l4", feature = "g4"))]
+#[cfg(any(feature = "f3", feature = "l4", feature = "g4", feature = "wb"))]
 use crate::pac::dma1 as dma_p;
 
 #[cfg(not(any(feature = "h7", feature = "f4", feature = "l5")))]
@@ -48,9 +52,9 @@ pub enum SpiInterrupt {
 #[derive(Clone, Copy)]
 pub enum SpiDevice {
     One,
-    #[cfg(not(feature = "f3x4"))]
+    #[cfg(not(any(feature = "f3x4", feature = "wb")))]
     Two,
-    #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0")))]
+    #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))]
     Three,
 }
 
@@ -110,7 +114,7 @@ impl Default for SpiConfig {
     }
 }
 
-/// SPI peripheral operating in full duplex master mode
+/// Represents an Serial Peripheral Interface (SPI) peripheral.
 pub struct Spi<S> {
     regs: S,
     device: SpiDevice,
@@ -135,11 +139,11 @@ where
                 #[cfg(not(feature = "f301"))] // todo: Not sure what's going on  here.
                 rcc_en_reset!(apb2, spi1, rcc);
             }
-            #[cfg(not(feature = "f3x4"))]
+            #[cfg(not(any(feature = "f3x4", feature = "wb")))]
             SpiDevice::Two => {
                 rcc_en_reset!(apb1, spi2, rcc);
             }
-            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0")))]
+            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))]
             SpiDevice::Three => {
                 cfg_if! {
                     // Note `sp3en` mixed with `spi3rst`; why we can't use the usual macro.
@@ -390,8 +394,6 @@ where
 
         // todo: Pri and Circular as args?
 
-        // todo: Include muxing for G and L5? Or handle that s
-
         // A DMA access is requested when the TXE or RXNE enable bit in the SPIx_CR2 register is
         // set. Separate requests must be issued to the Tx and Rx buffers.
         // In transmission, a DMA request is issued each time TXE is set to 1. The DMA then
@@ -408,9 +410,9 @@ where
         #[cfg(any(feature = "f3", feature = "l4"))]
         let tx_channel = match self.device {
             SpiDevice::One => DmaInput::Spi1Tx.dma1_channel(),
-            #[cfg(not(feature = "f3x4"))]
+            #[cfg(not(any(feature = "f3x4", feature = "wb")))]
             SpiDevice::Two => DmaInput::Spi2Tx.dma1_channel(),
-            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0")))]
+            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))]
             SpiDevice::Three => panic!(
                 "DMA on SPI3 is not supported. If it is for your MCU, please submit an issue \
                 or PR on Github."
@@ -459,6 +461,8 @@ where
             Default::default(),
         );
 
+        // atomic::compiler_fence(Ordering::Release);  // todo ?
+
         // 3. Enable DMA Tx buffer in the TXDMAEN bit in the SPI_CR2 register, if DMA Tx is used.
         self.regs.cr2.modify(|_, w| w.txdmaen().set_bit());
 
@@ -476,14 +480,16 @@ where
     {
         let (ptr, len) = (buf.as_mut_ptr(), buf.len());
 
+        // atomic::compiler_fence(Ordering::Release);  // todo ?
+
         self.regs.cr2.modify(|_, w| w.rxdmaen().set_bit());
 
         #[cfg(any(feature = "f3", feature = "l4"))]
         let channel = match self.device {
             SpiDevice::One => DmaInput::Spi1Rx.dma1_channel(),
-            #[cfg(not(feature = "f3x4"))]
+            #[cfg(not(any(feature = "f3x4", feature = "wb")))]
             SpiDevice::Two => DmaInput::Spi2Rx.dma1_channel(),
-            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0")))]
+            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))]
             _ => panic!(
                 "DMA on SPI3 is not supported. If it is for your MCU, please submit an issue \
                 or PR on Github."
@@ -493,9 +499,9 @@ where
         #[cfg(feature = "l4")]
         match self.device {
             SpiDevice::One => dma.channel_select(DmaInput::Spi1Rx),
-            #[cfg(not(feature = "f3x4"))]
+            #[cfg(not(any(feature = "f3x4", feature = "wb")))]
             SpiDevice::Two => dma.channel_select(DmaInput::Spi2Rx),
-            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0")))]
+            #[cfg(not(any(feature = "f3x4", feature = "f410", feature = "g0", feature = "wb")))]
             _ => unimplemented!(),
         };
 
@@ -520,8 +526,12 @@ where
         // todo: Set rxne or something to start?
     }
 
+    // todo: pub fn transfer_dma()?
+
     #[cfg(not(any(feature = "g0", feature = "h7", feature = "f4", feature = "l5")))]
-    /// Stop a DMA transfer. Run this after each transfer (?) Mandatory(?)
+    /// Stop a DMA transfer. Stops the channel, and disables the `txdmaen` and `rxdmaen` bits.
+    /// Run this after each transfer completes - you may wish to do this in an interrupt
+    /// (eg DMA transfer complete) instead of blocking.
     pub fn stop_dma<D>(&mut self, channel: DmaChannel, dma: &mut Dma<D>)
     where
         D: Deref<Target = dma_p::RegisterBlock>,
@@ -530,7 +540,7 @@ where
         // 1. Disable DMA streams for Tx and Rx in the DMA registers, if the streams are used.
         dma.stop(channel);
         // 2. Disable the SPI by following the SPI disable procedure:
-        self.disable();
+        // self.disable(); // todo: This probably isn't required.
         // 3. Disable DMA Tx and Rx buffers by clearing the TXDMAEN and RXDMAEN bits in the
         // SPI_CR2 register, if DMA Tx and/or DMA Rx are used.
         self.regs.cr2.modify(|_, w| {
