@@ -2,7 +2,10 @@
 
 use num_traits::float::Float;
 
-use embedded_hal::timer::{CountDown, Periodic};
+use embedded_hal::{
+    blocking::delay::{DelayMs, DelayUs},
+    timer::{CountDown, Periodic},
+};
 
 use void::Void;
 
@@ -23,7 +26,7 @@ use paste::paste;
 /// Used for when attempting to set a timer period that is out of range.
 pub struct ValueError {}
 
-/// Hardware timers
+/// Represents a timer peripheral.
 pub struct Timer<TIM> {
     clock_speed: u32, // Associated timer clock speed in Hz.
     tim: TIM,         // Register block for the specific timer.
@@ -197,41 +200,6 @@ impl OutputCompare {
 
 macro_rules! hal {
     ($TIMX:ident, $tim:ident, $apb:expr) => {
-        impl Periodic for Timer<pac::$TIMX> {}
-
-        impl CountDown for Timer<pac::$TIMX> {
-            type Time = f32;
-
-            fn start<T>(&mut self, timeout: T)
-            where
-                T: Into<f32>,  // Hz.
-            {
-                self.disable();
-
-                self.set_freq(timeout.into()).ok();
-
-                // Trigger an update event to load the prescaler value to the clock
-                // NOTE(write): uses all bits in this register.
-                self.tim.egr.write(|w| w.ug().set_bit());
-                // The above line raises an update event which will indicate
-                // that the timer is already finished. Since this is not the case,
-                // it should be cleared
-                self.clear_interrupt(TimerInterrupt::Update);
-
-                // start counter
-                self.enable();
-            }
-
-            fn wait(&mut self) -> nb::Result<(), Void> {
-                if self.tim.sr.read().uif().bit_is_clear() {
-                    Err(nb::Error::WouldBlock)
-                } else {
-                    self.clear_interrupt(TimerInterrupt::Update);
-                    Ok(())
-                }
-            }
-        }
-
         impl Timer<pac::$TIMX> {
             paste! {
                 /// Configures a TIM peripheral as a periodic count down timer
@@ -314,12 +282,6 @@ macro_rules! hal {
                 self.tim.cr1.read().cen().bit_is_set()
             }
 
-            /// Releases the TIM peripheral
-            pub fn free(mut self) -> pac::$TIMX {
-                self.disable();
-                self.tim
-            }
-
             /// Set the timer frequency, in Hz. Overrides the period or frequency set
             /// in the constructor. If you use `center` aligned PWM, make sure to
             /// enter twice the freq you normally would.
@@ -352,6 +314,86 @@ macro_rules! hal {
             pub fn reset_countdown(&mut self) {
                 self.tim.cnt.write(|w| unsafe { w.bits(0) });
             }
+
+            /// Read the current counter value.
+            pub fn countdown(&self) -> u32 {
+                self.tim.cnt.read().bits()
+            }
+        }
+
+        impl DelayMs<u32> for Timer<pac::$TIMX> {
+            fn delay_ms(&mut self, ms: u32) {
+                self.delay_us(ms as u32 * 1_000);
+            }
+        }
+
+        impl DelayMs<u16> for Timer<pac::$TIMX> {
+            fn delay_ms(&mut self, ms: u16) {
+                self.delay_us(ms as u32 * 1_000);
+            }
+        }
+
+        impl DelayMs<u8> for Timer<pac::$TIMX> {
+            fn delay_ms(&mut self, ms: u8) {
+                self.delay_us(ms as u32 * 1_000);
+            }
+        }
+
+        impl DelayUs<u32> for Timer<pac::$TIMX> {
+            fn delay_us(&mut self, us: u32) {
+                self.set_freq(1. / (us as f32 * 1_000.)).ok();
+                self.reset_countdown();
+                self.enable();
+                while self.countdown() != 0 {}
+                self.disable();
+            }
+        }
+
+        impl DelayUs<u16> for Timer<pac::$TIMX> {
+            fn delay_us(&mut self, us: u16) {
+                self.delay_us(us as u32);
+            }
+        }
+
+        impl DelayUs<u8> for Timer<pac::$TIMX> {
+            fn delay_us(&mut self, us: u8) {
+                self.delay_us(us as u32);
+            }
+        }
+
+         impl Periodic for Timer<pac::$TIMX> {}
+
+        impl CountDown for Timer<pac::$TIMX> {
+            type Time = f32;
+
+            fn start<T>(&mut self, timeout: T)
+            where
+                T: Into<f32>,  // Hz.
+            {
+                self.disable();
+
+                self.set_freq(timeout.into()).ok();
+
+                // Trigger an update event to load the prescaler value to the clock
+                // NOTE(write): uses all bits in this register.
+                self.tim.egr.write(|w| w.ug().set_bit());
+                // The above line raises an update event which will indicate
+                // that the timer is already finished. Since this is not the case,
+                // it should be cleared
+                self.clear_interrupt(TimerInterrupt::Update);
+
+                // start counter
+                self.enable();
+            }
+
+            fn wait(&mut self) -> nb::Result<(), Void> {
+                if self.tim.sr.read().uif().bit_is_clear() {
+                    Err(nb::Error::WouldBlock)
+                } else {
+                    self.clear_interrupt(TimerInterrupt::Update);
+                    Ok(())
+                }
+            }
         }
     }
 }
@@ -724,7 +766,13 @@ pwm_features!(TIM2, u16);
 #[cfg(not(any(feature = "l5", feature = "g070", feature = "g4", feature = "f410")))]
 pwm_features!(TIM2, u32);
 
-#[cfg(not(any(feature = "f301", feature = "l4x1", feature = "l4x3", feature = "f410",)))]
+#[cfg(not(any(
+    feature = "f301",
+    feature = "l4x1",
+    feature = "l4x3",
+    feature = "f410",
+    feature = "wb"
+)))]
 hal!(TIM3, tim3, 1);
 
 #[cfg(not(any(
@@ -732,7 +780,8 @@ hal!(TIM3, tim3, 1);
     feature = "l4x3",
     feature = "l5",
     feature = "f410",
-    feature = "g0"
+    feature = "g0",
+    feature = "wb",
 )))]
 pwm_features!(TIM3, u16);
 
@@ -746,9 +795,11 @@ cfg_if! {
         feature = "f410",
         feature = "l4x1",
         feature = "l4x2",
+        feature = "l412", // todo: 412 workaround
         feature = "l4x3",
         feature = "l552",
         feature = "g0",
+        feature = "wb",
     )))] {
         hal!(TIM4, tim4, 1);
     }
@@ -761,9 +812,11 @@ cfg_if! {
         feature = "f410",
         feature = "l4x1",
         feature = "l4x2",
+        feature = "l412", // todo: 412 workaround
         feature = "l4x3",
         feature = "l5",
         feature = "g0",
+        feature = "wb",
     )))] {
         pwm_features!(TIM4, u16);
     }
@@ -802,7 +855,8 @@ cfg_if! {
         feature = "g031",
         feature = "g041",
         feature = "g070",
-        feature = "g030"
+        feature = "g030",
+        feature = "wb",
     )))] {
         hal!(TIM6, tim6, 1);
     }
@@ -816,7 +870,8 @@ cfg_if! {
     feature = "f411",
     feature = "g031",
     feature = "g041",
-    feature = "g030"
+    feature = "g030",
+    feature = "wb",
 )))]
 hal!(TIM7, tim7, 1);
 
@@ -836,7 +891,7 @@ hal!(TIM8, tim8, 2);
     feature = "g031",
     feature = "g031",
     feature = "g041",
-    feature = "g030"
+    feature = "g030",
 )))]
 hal!(TIM15, tim15, 2);
 
@@ -847,6 +902,7 @@ cfg_if! {
     if #[cfg(not(any(
         feature = "l4x1",
         feature = "l4x2",
+        feature = "l412", // todo: 412 workaround
         feature = "l4x3",
         feature = "f4",
     )))] {
