@@ -15,7 +15,7 @@ use core::ops::Deref;
 
 #[cfg(feature = "g0")]
 use crate::pac::dma as dma_p;
-#[cfg(any(feature = "f3", feature = "l4", feature = "g4"))]
+#[cfg(any(feature = "f3", feature = "l4", feature = "g4", feature = "wb"))]
 use crate::pac::dma1 as dma_p;
 
 #[cfg(not(any(feature = "h7", feature = "f4", feature = "l5")))]
@@ -40,6 +40,14 @@ pub enum StopBits {
     S1_5 = 0b11,
 }
 
+#[derive(Clone, Copy, PartialEq)]
+/// Parity control enable/disable, and even/odd selection (USART_CR1, PCE and PS)
+pub enum Parity {
+    EnabledEven,
+    EnabledOdd,
+    Disabled,
+}
+
 #[derive(Clone, Copy)]
 #[repr(u8)]
 /// The length of word to transmit and receive. (USART_CR1, M)
@@ -66,6 +74,7 @@ impl WordLen {
 /// Specify the Usart device to use. Used internally for setting the appropriate APB.
 pub enum UsartDevice {
     One,
+    #[cfg(not(feature = "wb"))]
     Two,
     #[cfg(not(any(
         feature = "f401",
@@ -74,7 +83,8 @@ pub enum UsartDevice {
         feature = "f412",
         feature = "f413",
         feature = "l4x1",
-        feature = "g0"
+        feature = "g0",
+        feature = "wb",
     )))]
     Three,
     // Four,  todo
@@ -113,6 +123,7 @@ pub struct UsartConfig {
     word_len: WordLen,
     stop_bits: StopBits,
     oversampling: OverSampling,
+    parity: Parity,
 }
 
 impl Default for UsartConfig {
@@ -121,6 +132,7 @@ impl Default for UsartConfig {
             word_len: WordLen::W8,
             stop_bits: StopBits::S1,
             oversampling: OverSampling::O16,
+            parity: Parity::Disabled,
         }
     }
 }
@@ -149,6 +161,7 @@ where
             UsartDevice::One => {
                 rcc_en_reset!(apb2, usart1, rcc);
             }
+            #[cfg(not(feature = "wb"))]
             UsartDevice::Two => {
                 cfg_if! {
                     if #[cfg(not(feature = "f4"))] {
@@ -168,7 +181,8 @@ where
                 feature = "f412",
                 feature = "f413",
                 feature = "l4x1",
-                feature = "g0"
+                feature = "g0",
+                feature = "wb",
             )))]
             UsartDevice::Three => {
                 cfg_if! {
@@ -195,14 +209,27 @@ where
             config,
         };
 
-        // This should already be disabled on power up, but disable here just in case:
+        // This should already be disabled on power up, but disable here just in case;
+        // some bits can't be set with USART enabled.
         result.regs.cr1.modify(|_, w| w.ue().clear_bit());
         while result.regs.cr1.read().ue().bit_is_set() {}
 
-        result
-            .regs
-            .cr1
-            .modify(|_, w| w.over8().bit(result.config.oversampling as u8 != 0));
+        #[cfg(not(any(feature = "f3", feature = "f4")))]
+        let word_len_bits = result.config.word_len.bits();
+
+        result.regs.cr1.modify(|_, w| {
+            w.over8().bit(result.config.oversampling as u8 != 0);
+            w.pce().bit(result.config.parity != Parity::Disabled);
+            w.ps().bit(result.config.parity == Parity::EnabledOdd);
+            cfg_if! {
+                if #[cfg(any(feature = "f3", feature = "f4"))] {
+                    return w.m().bit(result.config.word_len as u8 != 0);
+                } else {
+                    w.m1().bit(word_len_bits.0 != 0);
+                    return w.m0().bit(word_len_bits.1 != 0);
+                }
+            }
+        });
 
         // Set up transmission. See L44 RM, section 38.5.2: "Character Transmission Procedures".
         // 1. Program the M bits in USART_CR1 to define the word length.
@@ -391,6 +418,7 @@ where
         #[cfg(any(feature = "f3", feature = "l4"))]
         let channel = match self.device {
             UsartDevice::One => DmaInput::Usart1Tx.dma1_channel(),
+            #[cfg(not(feature = "wb"))]
             UsartDevice::Two => DmaInput::Usart2Tx.dma1_channel(),
             #[cfg(not(any(
                 feature = "f401",
@@ -399,7 +427,8 @@ where
                 feature = "f412",
                 feature = "f413",
                 feature = "l4x1",
-                feature = "g0"
+                feature = "g0",
+                feature = "wb",
             )))]
             UsartDevice::Three => DmaInput::Usart3Tx.dma1_channel(),
         };
@@ -408,16 +437,9 @@ where
         #[cfg(feature = "l4")]
         match self.device {
             UsartDevice::One => dma.channel_select(DmaInput::Usart1Tx),
+            #[cfg(not(feature = "wb"))]
             UsartDevice::Two => dma.channel_select(DmaInput::Usart2Tx),
-            #[cfg(not(any(
-                feature = "f401",
-                feature = "f410",
-                feature = "f411",
-                feature = "f412",
-                feature = "f413",
-                feature = "l4x1",
-                feature = "g0"
-            )))]
+            #[cfg(not(feature = "l4x1"))]
             UsartDevice::Three => dma.channel_select(DmaInput::Usart3Tx),
         }
 
@@ -476,6 +498,7 @@ where
         #[cfg(any(feature = "f3", feature = "l4"))]
         let channel = match self.device {
             UsartDevice::One => DmaInput::Usart1Rx.dma1_channel(),
+            #[cfg(not(feature = "wb"))]
             UsartDevice::Two => DmaInput::Usart2Rx.dma1_channel(),
             #[cfg(not(any(
                 feature = "f401",
@@ -484,7 +507,8 @@ where
                 feature = "f412",
                 feature = "f413",
                 feature = "l4x1",
-                feature = "g0"
+                feature = "g0",
+                feature = "wb",
             )))]
             UsartDevice::Three => DmaInput::Usart3Rx.dma1_channel(),
         };
@@ -493,15 +517,7 @@ where
         match self.device {
             UsartDevice::One => dma.channel_select(DmaInput::Usart1Rx),
             UsartDevice::Two => dma.channel_select(DmaInput::Usart2Rx),
-            #[cfg(not(any(
-                feature = "f401",
-                feature = "f410",
-                feature = "f411",
-                feature = "f412",
-                feature = "f413",
-                feature = "l4x1",
-                feature = "g0"
-            )))]
+            #[cfg(not(feature = "l4x1"))]
             UsartDevice::Three => dma.channel_select(DmaInput::Usart3Rx),
         }
 
