@@ -13,7 +13,7 @@ macro_rules! rcc_en_reset {
                 $rcc.apb1enr.modify(|_, w| w.[<$periph en>]().set_bit());
                 $rcc.apb1rstr.modify(|_, w| w.[<$periph rst>]().set_bit());
                 $rcc.apb1rstr.modify(|_, w| w.[<$periph rst>]().clear_bit());
-            } else if #[cfg(any(feature = "l4", feature = "l5", feature = "g4"))] {
+            } else if #[cfg(any(feature = "l4", feature = "l5", feature = "g4", feature = "wb"))] {
                 $rcc.apb1enr1.modify(|_, w| w.[<$periph en>]().set_bit());
                 $rcc.apb1rstr1.modify(|_, w| w.[<$periph rst>]().set_bit());
                 $rcc.apb1rstr1.modify(|_, w| w.[<$periph rst>]().clear_bit());
@@ -26,6 +26,8 @@ macro_rules! rcc_en_reset {
                 $rcc.apb1lrstr.modify(|_, w| w.[<$periph rst>]().set_bit());
                 $rcc.apb1lrstr.modify(|_, w| w.[<$periph rst>]().clear_bit());
             }
+            // todo: apb1enr2 on L5? Currently we only use it with USB, which is handled in
+            // todo `usb.rs`.
         }}
     };
     (apb2, $periph:expr, $rcc:expr) => {
